@@ -8,8 +8,8 @@
 #![cfg_attr(docsrs, feature(doc_auto_cfg))]
 #![warn(missing_docs, clippy::unwrap_used)]
 #![doc(
-	html_logo_url = "https://raw.githubusercontent.com/orhun/git-cliff/main/website/static/img/git-cliff.png",
-	html_favicon_url = "https://raw.githubusercontent.com/orhun/git-cliff/main/website/static/favicon/favicon.ico"
+    html_logo_url = "https://raw.githubusercontent.com/orhun/git-cliff/main/website/static/img/git-cliff.png",
+    html_favicon_url = "https://raw.githubusercontent.com/orhun/git-cliff/main/website/static/favicon/favicon.ico"
 )]
 
 /// Changelog generator.
@@ -35,14 +35,13 @@ pub mod remote;
 /// Git repository.
 #[cfg(feature = "repo")]
 pub mod repo;
+/// Release statistics.
+pub mod statistics;
 /// Git tag.
 pub mod tag;
 /// Template engine.
 pub mod template;
 
-#[macro_use]
-extern crate log;
-
 /// Default configuration file.
 pub const DEFAULT_CONFIG: &str = "cliff.toml";
 /// Default output file.
